# Advanced Practices
### On this page
  * [Automation to Trigger an End-of-Life Process](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management-advanced#automation-to-trigger-an-end-of-life-process)
  * [Using SAP LeanIX Architecture and Road Map Planning for Obsolescence Risk Management](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management-advanced#using-sap-leanix-architecture-and-road-map-planning-for-obsolescence-risk-management)
  * [Aggregating Obsolescence Risk for Self-Built Software](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management-advanced#aggregating-obsolescence-risk-for-self-built-software)
  * [Aggregating Obsolescence Risk Through Technical Platforms](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management-advanced#aggregating-obsolescence-risk-through-technical-platforms)


Use automation and SAP LeanIX Architecture and Road Map Planning to advance the obsolescence risk management use case.
You can advance your use case by using more SAP LeanIX features. Here are a couple of best practices and examples to gain more insights and improve your efficiency:
